@@ -1,5 +1,9 @@
-class ERROR_CODE:
+from enum import Enum
+
+
+class ERROR_CODE(Enum):
     INVALID_REQUEST = "INVALID_REQUEST"
     RESOURCE_NOT_FOUND = "RESOURCE_NOT_FOUND"
     AUTHORIZATION_ERROR = "AUTHORIZATION_ERROR"
     INTERNAL_ERROR = "INTERNAL_ERROR"
+    PAYMENT_ERROR = "PAYMENT_ERROR"
