@@ -6,10 +6,20 @@ from .validators import validate_number
 
 class StringField(models.CharField):
     """
-    Custom field with pre-defined max length to be used as primary key,
-    for pk referencing purposes, or anywhere else a short string makes sense.
-    The max length is determined based on the length of UUID. Typically
-    UUID have 36 characters but we added 4 more for extra breathing room.
+    A field used to store a reasonable-sized string. It's a shortcut
+    to always having to declare max_length on CharField. Value stored
+    in this field should be smaller that what TextField can store.
+    """
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        kwargs["max_length"] = 150
+        super().__init__(*args, **kwargs)
+
+
+class ShortStringField(models.CharField):
+    """
+    A field used to store typically single-word type of strings. Examples
+    include a primary key value, status and type values, etc.
     """
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -17,7 +27,7 @@ class StringField(models.CharField):
         super().__init__(*args, **kwargs)
 
 
-class PrimaryKeyField(StringField):
+class PrimaryKeyField(ShortStringField):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         kwargs["editable"] = False
         kwargs["primary_key"] = True
@@ -25,7 +35,7 @@ class PrimaryKeyField(StringField):
         super().__init__(*args, **kwargs)
 
 
-class PhoneNumberField(StringField):
+class PhoneNumberField(ShortStringField):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         kwargs["validators"] = [validate_number]
         super().__init__(*args, **kwargs)
