@@ -21,9 +21,16 @@ def resolve_logging() -> Dict[str, Any]:
     return {
         "version": 1,
         "disable_existing_loggers": False,
+        "formatters": {
+            "default": {  # Needed to prettify logs (especially for mini-huey/background task queue) to match gunicon logs format.
+                "style": "{",
+                "format": "[{asctime}] [{process}] [{levelname}] {message}",
+            },
+        },
         "handlers": {
             "console": {
                 "class": "logging.StreamHandler",
+                "formatter": "default",
             },
         },
         "root": {
@@ -35,6 +42,6 @@ def resolve_logging() -> Dict[str, Any]:
 
 def resolve_file_storage() -> str:
     if resolve_environment() == "testing":
-        return "django.core.files.storage.FileSystemStorage"
+        return "inmemorystorage.InMemoryStorage"
 
     return "storages.backends.s3boto3.S3Boto3Storage"
