@@ -1,6 +1,6 @@
-from typing import Any, Optional
+from typing import Any, Optional, Dict, List
 from rest_framework.response import Response
-from rest_framework.test import APIClient
+from rest_framework.test import APIClient, APITestCase
 
 
 class BaseAPIClient(APIClient):
@@ -25,5 +25,17 @@ class BaseAPIClient(APIClient):
         return super().delete(path, HTTP_ACCEPT=self.ACCEPT_HEADER, **extra)
 
 
+class BaseAPITestCase(APITestCase):
+    def render_page(
+        self, count: int, results: List[Any], next: str = None, previous: str = None
+    ) -> Dict[str, Any]:
+        return {
+            "count": count,
+            "next": next,
+            "previous": previous,
+            "results": results,
+        }
+
+
 class APIClientV1_0(BaseAPIClient):
     ACCEPT_HEADER = "application/json"
