@@ -1,7 +1,7 @@
 import logging
 from typing import Any, Dict
 from django.http import Http404
-from django.core.exceptions import PermissionDenied
+from django.core.exceptions import PermissionDenied, ObjectDoesNotExist
 from rest_framework import exceptions, status
 from rest_framework.response import Response
 from rest_framework.views import set_rollback
@@ -12,10 +12,14 @@ from .responses import generic_error
 def _extract_message_from_detail(detail: Any) -> str:
     if isinstance(detail, list):
         errors = [_extract_message_from_detail(d) for d in detail]
-        return "\n".join(detail)
+        # Return the first error. Subsequent errors will be shown once the user fixes the first one.
+        # This is so we can keep the "message" returned in the error as a whole string.
+        return errors[0]
     elif isinstance(detail, dict):
-        errors = [_extract_message_from_detail(d) for d in detail.values()]
-        return "\n".join(errors)
+        errors = [_extract_message_from_detail(v) for v in detail.values()]
+        # Return the first error. Subsequent errors will be shown once the user fixes the first one.
+        # This is so we can keep the "message" returned in the error as a whole string.
+        return errors[0]
     else:
         return str(detail)
 
@@ -24,7 +28,7 @@ def exception_handler(exc: Exception, context: Dict[str, Any]) -> Response:
     """
     Mostly copied from https://github.com/encode/django-rest-framework/blob/master/rest_framework/views.py#L71
     """
-    if isinstance(exc, Http404):
+    if isinstance(exc, Http404) or isinstance(exc, ObjectDoesNotExist):
         return generic_error(
             status.HTTP_404_NOT_FOUND,
             ERROR_CODE.RESOURCE_NOT_FOUND,
@@ -41,7 +45,7 @@ def exception_handler(exc: Exception, context: Dict[str, Any]) -> Response:
     if isinstance(exc, exceptions.APIException):
         set_rollback()
         return generic_error(
-            status.HTTP_400_BAD_REQUEST,
+            exc.status_code,
             ERROR_CODE.INVALID_REQUEST,
             _extract_message_from_detail(exc.detail),
         )
